summaryrefslogtreecommitdiff
path: root/source3/include/rpc_misc.h
diff options
context:
space:
mode:
Diffstat (limited to 'source3/include/rpc_misc.h')
-rw-r--r--source3/include/rpc_misc.h11
1 files changed, 9 insertions, 2 deletions
diff --git a/source3/include/rpc_misc.h b/source3/include/rpc_misc.h
index 091ba3395e..7b71e80c55 100644
--- a/source3/include/rpc_misc.h
+++ b/source3/include/rpc_misc.h
@@ -264,13 +264,20 @@ typedef struct {
* Domain SID structures
**********************************************************************/
/* DOM_RID2 - domain RID structure for ntlsa pipe */
typedef struct {
uint8 type; /* value is SID_NAME_USE enum */
uint32 rid;
uint32 rid_idx; /* referenced domain index */
-} DOM_RID2;
+} DOM_RID;
+/* DOM_RID2 - second domain RID structure for ntlsa pipe */
+typedef struct {
+ uint8 type; /* value is SID_NAME_USE enum */
+ uint32 rid;
+ uint32 rid_idx; /* referenced domain index */
+ uint32 unknown;
+} DOM_RID2;
typedef struct { /* DOM_RID3 - domain RID structure for samr pipe */
uint32 rid; /* domain-relative (to a SID) id */
@@ -264,13 +264,20 @@ typedef struct {
* Domain SID structures
**********************************************************************/
-/* DOM_RID2 - domain RID structure for ntlsa pipe */
+/* DOM_RID - domain RID structure for ntlsa pipe */
typedef struct {
uint8 type; /* value is SID_NAME_USE enum */